@@ -1,6 +1,6 @@
 /* io.c
  *
- * $Id: io.c,v 1.19 2000/02/04 19:02:04 bazsi Exp $ */
+ * $Id: io.c,v 1.20 2000/03/15 16:41:53 bazsi Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -319,6 +319,7 @@ static int do_read(struct abstract_read **r, UINT32 length, UINT8 *buffer)
 	{
 	  debug("Read EOF on fd %i.\n", closure->fd);
 	  return A_EOF;
+	  return 0;
 	}
       if (res > 0)
 	return res;
@@ -610,7 +611,7 @@ static void do_kill_fd(struct resource *r)
 	 * killed files. For now, using the zero reason will supress calling
 	 * of any close callbacks. */
 	if (r->alive)
-		close_fd(fd, 0);
+		closekill_fd(fd, 0);
 }
 
 /* Initializes a file structure, and adds it to the backend's list. */
@@ -845,7 +846,7 @@ static int connect_inet_socket(struct address_info *c, int fd)
 
 	if (inet_address2sockaddr_in(c, sizeof(in), (struct sockaddr *) &in)) {
 		verbose("connecting fd %i to inetaddr %S, port %i\n", fd, i->ip, i->port);
-		if (connect(fd, (struct sockaddr *) &in, sizeof(in)) < -1) {
+		if (connect(fd, (struct sockaddr *) &in, sizeof(in)) < 0) {
 			switch (errno) {
 			case EWOULDBLOCK:
 				return 1;
@@ -906,8 +907,10 @@ static int unix_address2sockaddr_un(struct address_info *c, int sasize, struct s
 
 static int bind_unix_socket(struct address_info *c, int fd)
 {
+	CAST(unix_address_info, a, c);
 	struct sockaddr_un un;
-
+	
+	verbose("binding fd %i, unixaddr: %S\n", fd, a->path);
 	if (unix_address2sockaddr_un(c, sizeof(un), (struct sockaddr *) &un)) {
 		struct stat st;
 
@@ -929,10 +932,12 @@ static int bind_unix_socket(struct address_info *c, int fd)
 
 static int connect_unix_socket(struct address_info *c, int fd)
 {
+	CAST(unix_address_info, a, c);
 	struct sockaddr_un un;
 
+	verbose("connecting fd %i, unixaddr: %S\n", fd, a->path);
 	if (unix_address2sockaddr_un(c, sizeof(un), (struct sockaddr *) &un)) {
-		if (connect(fd, (struct sockaddr *) &un, sizeof(un)) < -1) {
+		if (connect(fd, (struct sockaddr *) &un, sizeof(un)) < 0) {
 			switch (errno) {
 			case EWOULDBLOCK:
 				return 1;
